summaryrefslogtreecommitdiff
path: root/editeng
diff options
context:
space:
mode:
authorCaolán McNamara <caolanm@redhat.com>2013-09-23 07:19:08 +0100
committerCaolán McNamara <caolanm@redhat.com>2013-09-25 19:24:23 +0200
commit98de5b40c8a3fd4e57477b6d994e3b1472207f71 (patch)
tree567fdbbaecbddbfc19f28a08da5d1f6d5207748c /editeng
parent0552a91acde9dce28c0d92c552d21fbadfcb9184 (diff)
Related: fdo#38838 remove UniString::EqualsIgnoreCaseAscii
Change-Id: Ib5c3a2daa4a48bc286b14fa2cebb3306ea0012bc
Diffstat (limited to 'editeng')
-rw-r--r--editeng/source/rtf/svxrtf.cxx16
-rw-r--r--editeng/source/uno/unofdesc.cxx2
2 files changed, 9 insertions, 9 deletions
diff --git a/editeng/source/uno/unofdesc.cxx b/editeng/source/uno/unofdesc.cxx
index b1315861e34c..cd52e33e2157 100644
--- a/editeng/source/uno/unofdesc.cxx
+++ b/editeng/source/uno/unofdesc.cxx
@@ -44,7 +44,7 @@ void SvxUnoFontDescriptor::ConvertToFont( const awt::FontDescriptor& rDesc, Font
rFont.SetStyleName( rDesc.StyleName );
rFont.SetSize( Size( rDesc.Width, rDesc.Height ) );
rFont.SetFamily( (FontFamily)rDesc.Family );
- rFont.SetCharSet( (CharSet)rDesc.CharSet );
+ rFont.SetCharSet( (rtl_TextEncoding)rDesc.CharSet );
rFont.SetPitch( (FontPitch)rDesc.Pitch );
rFont.SetOrientation( (short)(rDesc.Orientation*10) );
rFont.SetKerning( rDesc.Kerning );
diff --git a/editeng/source/rtf/svxrtf.cxx b/editeng/source/rtf/svxrtf.cxx
index 1f6f744e21b4..973d3f6aee72 100644
--- a/editeng/source/rtf/svxrtf.cxx
+++ b/editeng/source/rtf/svxrtf.cxx
@@ -42,7 +42,7 @@
using namespace ::com::sun::star;
-static CharSet lcl_GetDefaultTextEncodingForRTF()
+static rtl_TextEncoding lcl_GetDefaultTextEncodingForRTF()
{
OUString aLangString( Application::GetSettings().GetLanguageTag().getLanguage());
@@ -463,7 +463,7 @@ void SvxRTFParser::ReadFontTable()
OUString sAltNm, sFntNm;
sal_Bool bIsAltFntNm = sal_False, bCheckNewFont;
- CharSet nSystemChar = lcl_GetDefaultTextEncodingForRTF();
+ rtl_TextEncoding nSystemChar = lcl_GetDefaultTextEncodingForRTF();
pFont->SetCharSet( nSystemChar );
SetEncoding( nSystemChar );
@@ -516,7 +516,7 @@ void SvxRTFParser::ReadFontTable()
case RTF_FDECOR:
pFont->SetFamily( FAMILY_DECORATIVE );
break;
// for technical/symbolic font of the CharSet is changed!
case RTF_FTECH:
pFont->SetCharSet( RTL_TEXTENCODING_SYMBOL );
// deliberate fall through
@@ -526,14 +526,14 @@ void SvxRTFParser::ReadFontTable()
case RTF_FCHARSET:
if (-1 != nTokenValue)
{
- CharSet nCharSet = rtl_getTextEncodingFromWindowsCharset(
+ rtl_TextEncoding nrtl_TextEncoding = rtl_getTextEncodingFromWindowsCharset(
(sal_uInt8)nTokenValue);
- pFont->SetCharSet(nCharSet);
+ pFont->SetCharSet(nrtl_TextEncoding);
//When we're in a font, the fontname is in the font
//charset, except for symbol fonts I believe
- if (nCharSet == RTL_TEXTENCODING_SYMBOL)
- nCharSet = RTL_TEXTENCODING_DONTKNOW;
- SetEncoding(nCharSet);
+ if (nrtl_TextEncoding == RTL_TEXTENCODING_SYMBOL)
+ nrtl_TextEncoding = RTL_TEXTENCODING_DONTKNOW;
+ SetEncoding(nrtl_TextEncoding);
}
break;
case RTF_FPRQ:
@@ -516,7 +516,7 @@ void SvxRTFParser::ReadFontTable()
pFont->SetFamily( FAMILY_DECORATIVE );
break;
- // for technical/symbolic font of the CharSet is changed!
+ // for technical/symbolic font of the rtl_TextEncoding is changed!
case RTF_FTECH:
pFont->SetCharSet( RTL_TEXTENCODING_SYMBOL );